summaryrefslogtreecommitdiff
path: root/src/rekonqpage/newtabpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rekonqpage/newtabpage.h')
-rw-r--r--src/rekonqpage/newtabpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rekonqpage/newtabpage.h b/src/rekonqpage/newtabpage.h
index 36f79401..a33657ea 100644
--- a/src/rekonqpage/newtabpage.h
+++ b/src/rekonqpage/newtabpage.h
@@ -53,10 +53,10 @@ public:
explicit NewTabPage(QWebFrame *frame);
/**
* This method takes an about: url and loads
* the corresponding part of the new tab page
*/
- void generate(const KUrl &url = KUrl("about:home"));
+ void generate(const KUrl &url = KUrl("rekonq:home"));
private:
// these are the "high-level" functions to build the new tab page.
@@ -53,10 +53,10 @@ public:
explicit NewTabPage(QWebFrame *frame);
/**
- * This method takes an about: url and loads
+ * This method takes an rekonq: url and loads
* the corresponding part of the new tab page
*/